@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
 our $DATE = '2015-04-07'; # DATE
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -422,7 +422,10 @@ sub _process_script {
         last unless $cli->read_env;
         #$self->log_debug(["skipped file %s (script does not read env)", $filename]);
         my @content;
-        push @content, $cli->env_name . "\n\n";
+        push @content, "=over\n\n";
+        push @content, "=item * ", $cli->env_name, "\n\n";
+        push @content, "Specify additional command-line options\n\n";
+        push @content, "=back\n\n";
 
         $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT',
                                    {before_section=>'HOMEPAGE'});
@@ -479,6 +482,8 @@ sub _process_script {
                 "searched at ", @files_list, " (can be changed by specifying C<--config-path>). ",
                 "All found files will be read and merged.", "\n\n",
 
+                "To disable searching for configuration files, pass C<--no-config>.\n\n",
+
                 "Configuration file is in the format of L<IOD>, which is basically INI with ",
                 "some extra features. ",
                 ($cli->{subcommands} ? "Section names map to subcommand names. ":""), "\n\n",
@@ -598,7 +603,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.36 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
+This document describes version 0.37 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
 
 =head1 SYNOPSIS
 
